@@ -4,8 +4,7 @@ import openpyxl
 from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl.worksheet._read_only import ReadOnlyWorksheet
 from openpyxl.chartsheet.chartsheet import Chartsheet
-import tinytim.functions as tim
-
+import tinytim as tim
 
 
 Sheet = Union[Worksheet, ReadOnlyWorksheet, Chartsheet]
@@ -49,4 +48,4 @@ def read_excel_file(path: str, sheet_name: Optional[str] = None) -> dict:
             else:
                 rows.append(row)
 
-    return tim.combine_names_rows(column_names, rows)
\ No newline at end of file
+    return tim.utils.combine_names_rows(column_names, rows)
\ No newline at end of file
